#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .low_re_ke import low_re_ke as low_re_ke_cls
from .low_re_ke_index import low_re_ke_index as low_re_ke_index_cls
from .kato_launder_model import kato_launder_model as kato_launder_model_cls
from .production_limiter import production_limiter as production_limiter_cls
from .kw_vorticity_based_production import kw_vorticity_based_production as kw_vorticity_based_production_cls
from .kw_add_sas import kw_add_sas as kw_add_sas_cls
from .kw_add_des import kw_add_des as kw_add_des_cls
from .turb_add_sbes_sdes import turb_add_sbes_sdes as turb_add_sbes_sdes_cls
from .sbes_sdes_hybrid_model import sbes_sdes_hybrid_model as sbes_sdes_hybrid_model_cls
from .sbes_update_interval_k_omega import sbes_update_interval_k_omega as sbes_update_interval_k_omega_cls
from .sbes_sgs_option import sbes_sgs_option as sbes_sgs_option_cls
from .sbes_les_subgrid_dynamic_fvar import sbes_les_subgrid_dynamic_fvar as sbes_les_subgrid_dynamic_fvar_cls
from .turbulence_damping import turbulence_damping as turbulence_damping_cls
from .rke_cmu_rotation_term import rke_cmu_rotation_term as rke_cmu_rotation_term_cls
from .turb_non_newtonian import turb_non_newtonian as turb_non_newtonian_cls
from .non_newtonian_modification import non_newtonian_modification as non_newtonian_modification_cls
from .turb_pk_compressible import turb_pk_compressible as turb_pk_compressible_cls
from .thermal_p_function import thermal_p_function as thermal_p_function_cls
from .restore_sst_v61 import restore_sst_v61 as restore_sst_v61_cls

class turbulence_expert(Group):
    """
    'turbulence_expert' child.
    """

    fluent_name = "turbulence-expert"

    child_names = \
        ['low_re_ke', 'low_re_ke_index', 'kato_launder_model',
         'production_limiter', 'kw_vorticity_based_production', 'kw_add_sas',
         'kw_add_des', 'turb_add_sbes_sdes', 'sbes_sdes_hybrid_model',
         'sbes_update_interval_k_omega', 'sbes_sgs_option',
         'sbes_les_subgrid_dynamic_fvar', 'turbulence_damping',
         'rke_cmu_rotation_term', 'turb_non_newtonian',
         'non_newtonian_modification', 'turb_pk_compressible',
         'thermal_p_function', 'restore_sst_v61']

    _child_classes = dict(
        low_re_ke=low_re_ke_cls,
        low_re_ke_index=low_re_ke_index_cls,
        kato_launder_model=kato_launder_model_cls,
        production_limiter=production_limiter_cls,
        kw_vorticity_based_production=kw_vorticity_based_production_cls,
        kw_add_sas=kw_add_sas_cls,
        kw_add_des=kw_add_des_cls,
        turb_add_sbes_sdes=turb_add_sbes_sdes_cls,
        sbes_sdes_hybrid_model=sbes_sdes_hybrid_model_cls,
        sbes_update_interval_k_omega=sbes_update_interval_k_omega_cls,
        sbes_sgs_option=sbes_sgs_option_cls,
        sbes_les_subgrid_dynamic_fvar=sbes_les_subgrid_dynamic_fvar_cls,
        turbulence_damping=turbulence_damping_cls,
        rke_cmu_rotation_term=rke_cmu_rotation_term_cls,
        turb_non_newtonian=turb_non_newtonian_cls,
        non_newtonian_modification=non_newtonian_modification_cls,
        turb_pk_compressible=turb_pk_compressible_cls,
        thermal_p_function=thermal_p_function_cls,
        restore_sst_v61=restore_sst_v61_cls,
    )

    return_type = "<object object at 0x7f7d7fb8ee50>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .from_zone_type import from_zone_type as from_zone_type_cls
from .from_zone_name import from_zone_name as from_zone_name_cls
from .phase_25 import phase as phase_cls

class compute(Command):
    fluent_name = ...
    argument_names = ...
    from_zone_type: from_zone_type_cls = ...
    from_zone_name: from_zone_name_cls = ...
    phase: phase_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .list_properties_1 import list_properties as list_properties_cls
from .child_object_type_child_1 import child_object_type_child


class source_terms_child(ListObject[child_object_type_child]):
    """
    'child_object_type' of source_terms.
    """

    fluent_name = "child-object-type"

    command_names = \
        ['list_properties']

    _child_classes = dict(
        list_properties=list_properties_cls,
    )

    child_object_type: child_object_type_child = child_object_type_child
    """
    child_object_type of source_terms_child.
    """
    return_type = "<object object at 0x7f7d7faef0b0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .name import name as name_cls
from .surfaces_1 import surfaces as surfaces_cls
from .cellzones_1 import cellzones as cellzones_cls
from .cell_func_domain import cell_func_domain as cell_func_domain_cls

class fieldview_unstruct(Command):
    """
    Write a Fieldview unstructured combined file.
    
    Parameters
    ----------
        name : str
            'name' child.
        surfaces : typing.List[str]
            List of surfaces to export.
        cellzones : typing.List[str]
            List of cell zones to export.
        cell_func_domain : typing.List[str]
            'cell_func_domain' child.
    
    """

    fluent_name = "fieldview-unstruct"

    argument_names = \
        ['name', 'surfaces', 'cellzones', 'cell_func_domain']

    _child_classes = dict(
        name=name_cls,
        surfaces=surfaces_cls,
        cellzones=cellzones_cls,
        cell_func_domain=cell_func_domain_cls,
    )

    return_type = "<object object at 0x7f7d7ff634c0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .simulation_reports import simulation_reports as simulation_reports_cls
from .discrete_phase_1 import discrete_phase as discrete_phase_cls
from .fluxes import fluxes as fluxes_cls
from .flow import flow as flow_cls
from .modified_setting_options import modified_setting_options as modified_setting_options_cls
from .population_balance import population_balance as population_balance_cls
from .heat_exchange_1 import heat_exchange as heat_exchange_cls
from .system import system as system_cls
from .histogram_1 import histogram as histogram_cls
from .aero_optical_distortions import aero_optical_distortions as aero_optical_distortions_cls
from .forces import forces as forces_cls
from .mphase_summary import mphase_summary as mphase_summary_cls
from .particle_summary import particle_summary as particle_summary_cls
from .path_line_summary import path_line_summary as path_line_summary_cls
from .projected_surface_area import projected_surface_area as projected_surface_area_cls
from .summary_1 import summary as summary_cls
from .surface_integrals import surface_integrals as surface_integrals_cls
from .volume_integrals import volume_integrals as volume_integrals_cls

class report(Group):
    """
    'report' child.
    """

    fluent_name = "report"

    child_names = \
        ['simulation_reports', 'discrete_phase', 'fluxes', 'flow',
         'modified_setting_options', 'population_balance', 'heat_exchange',
         'system', 'histogram']

    command_names = \
        ['aero_optical_distortions', 'forces', 'mphase_summary',
         'particle_summary', 'path_line_summary', 'projected_surface_area',
         'summary', 'surface_integrals', 'volume_integrals']

    _child_classes = dict(
        simulation_reports=simulation_reports_cls,
        discrete_phase=discrete_phase_cls,
        fluxes=fluxes_cls,
        flow=flow_cls,
        modified_setting_options=modified_setting_options_cls,
        population_balance=population_balance_cls,
        heat_exchange=heat_exchange_cls,
        system=system_cls,
        histogram=histogram_cls,
        aero_optical_distortions=aero_optical_distortions_cls,
        forces=forces_cls,
        mphase_summary=mphase_summary_cls,
        particle_summary=particle_summary_cls,
        path_line_summary=path_line_summary_cls,
        projected_surface_area=projected_surface_area_cls,
        summary=summary_cls,
        surface_integrals=surface_integrals_cls,
        volume_integrals=volume_integrals_cls,
    )

    return_type = "<object object at 0x7f7d0bcf6930>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .zone_id import zone_id as zone_id_cls

class slit_face_zone(Command):
    """
    Slit a two-sided wall into two connected wall zones.
    
    Parameters
    ----------
        zone_id : int
            'zone_id' child.
    
    """

    fluent_name = "slit-face-zone"

    argument_names = \
        ['zone_id']

    _child_classes = dict(
        zone_id=zone_id_cls,
    )

    return_type = "<object object at 0x7f79a69cc530>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .file_name_1 import file_name as file_name_cls
from .surface_name_list_1 import surface_name_list as surface_name_list_cls
from .delimiter import delimiter as delimiter_cls
from .cell_func_domain import cell_func_domain as cell_func_domain_cls
from .location import location as location_cls

class ascii(Command):
    fluent_name = ...
    argument_names = ...
    file_name: file_name_cls = ...
    surface_name_list: surface_name_list_cls = ...
    delimiter: delimiter_cls = ...
    cell_func_domain: cell_func_domain_cls = ...
    location: location_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .general import general as general_cls
from .models_1 import models as models_cls
from .materials import materials as materials_cls
from .cell_zone_conditions import cell_zone_conditions as cell_zone_conditions_cls
from .boundary_conditions import boundary_conditions as boundary_conditions_cls
from .reference_values import reference_values as reference_values_cls
from .named_expressions import named_expressions as named_expressions_cls
from .mesh_interfaces import mesh_interfaces as mesh_interfaces_cls
from .geometry_3 import geometry as geometry_cls
from .physics import physics as physics_cls
from .reference_frames import reference_frames as reference_frames_cls

class setup(Group):
    """
    'setup' child.
    """

    fluent_name = "setup"

    child_names = \
        ['general', 'models', 'materials', 'cell_zone_conditions',
         'boundary_conditions', 'reference_values', 'named_expressions',
         'mesh_interfaces', 'geometry', 'physics', 'reference_frames']

    _child_classes = dict(
        general=general_cls,
        models=models_cls,
        materials=materials_cls,
        cell_zone_conditions=cell_zone_conditions_cls,
        boundary_conditions=boundary_conditions_cls,
        reference_values=reference_values_cls,
        named_expressions=named_expressions_cls,
        mesh_interfaces=mesh_interfaces_cls,
        geometry=geometry_cls,
        physics=physics_cls,
        reference_frames=reference_frames_cls,
    )

    return_type = "<object object at 0x7f7d0bfd4d50>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .list import list as list_cls
from .use_active import use_active as use_active_cls
from .restore_state import restore_state as restore_state_cls
from .copy import copy as copy_cls
from .read_1 import read as read_cls
from .write_1 import write as write_cls
from .display_states_child import display_states_child


class display_states(NamedObject[display_states_child], CreatableNamedObjectMixin[display_states_child]):
    fluent_name = ...
    command_names = ...

    def list(self, ):
        """
        'list' command.
        """

    def use_active(self, state_name: str):
        """
        'use_active' command.
        
        Parameters
        ----------
            state_name : str
                'state_name' child.
        
        """

    def restore_state(self, state_name: str):
        """
        Apply a display state to the active window.
        
        Parameters
        ----------
            state_name : str
                'state_name' child.
        
        """

    def copy(self, state_name: str):
        """
        Create a new display state with settings copied from an existing display state.
        
        Parameters
        ----------
            state_name : str
                'state_name' child.
        
        """

    def read(self, file_name: str):
        """
        Read display states from a file.
        
        Parameters
        ----------
            file_name : str
                'file_name' child.
        
        """

    def write(self, file_name: str, state_name: List[str]):
        """
        Write display states to a file.
        
        Parameters
        ----------
            file_name : str
                'file_name' child.
            state_name : typing.List[str]
                'state_name' child.
        
        """

    child_object_type = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .list_properties_1 import list_properties as list_properties_cls
from .child_object_type_child_1 import child_object_type_child


class solid_motion_axis_direction(ListObject[child_object_type_child]):
    fluent_name = ...
    command_names = ...

    def list_properties(self, object_at: int):
        """
        'list_properties' command.
        
        Parameters
        ----------
            object_at : int
                'object_at' child.
        
        """

    child_object_type = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .iterate_1 import iterate as iterate_cls
from .dual_time_iterate_1 import dual_time_iterate as dual_time_iterate_cls

class solve(Group):
    """
    'solve' child.
    """

    fluent_name = "solve"

    command_names = \
        ['iterate', 'dual_time_iterate']

    _child_classes = dict(
        iterate=iterate_cls,
        dual_time_iterate=dual_time_iterate_cls,
    )

    return_type = "<object object at 0x7f7d0bcbc730>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .name_2 import name as name_cls
from .chemical_formula import chemical_formula as chemical_formula_cls
from .density_2 import density as density_cls
from .viscosity_1 import viscosity as viscosity_cls
from .specific_heat_2 import specific_heat as specific_heat_cls
from .thermal_conductivity_2 import thermal_conductivity as thermal_conductivity_cls
from .premix_laminar_speed import premix_laminar_speed as premix_laminar_speed_cls
from .premix_laminar_thickness import premix_laminar_thickness as premix_laminar_thickness_cls
from .premix_unburnt_temp_1 import premix_unburnt_temp as premix_unburnt_temp_cls
from .premix_unburnt_cp import premix_unburnt_cp as premix_unburnt_cp_cls
from .premix_unburnt_density_1 import premix_unburnt_density as premix_unburnt_density_cls
from .premix_heat_trans_coeff_1 import premix_heat_trans_coeff as premix_heat_trans_coeff_cls
from .premix_critical_strain import premix_critical_strain as premix_critical_strain_cls
from .therm_exp_coeff import therm_exp_coeff as therm_exp_coeff_cls
from .absorption_coefficient_1 import absorption_coefficient as absorption_coefficient_cls
from .scattering_coefficient import scattering_coefficient as scattering_coefficient_cls
from .scattering_phase_function import scattering_phase_function as scattering_phase_function_cls
from .refractive_index import refractive_index as refractive_index_cls
from .mass_diffusivity import mass_diffusivity as mass_diffusivity_cls
from .species_1 import species as species_cls
from .reactions_1 import reactions as reactions_cls
from .reaction_mechs import reaction_mechs as reaction_mechs_cls
from .uds_diffusivity import uds_diffusivity as uds_diffusivity_cls
from .thermal_diffusivity import thermal_diffusivity as thermal_diffusivity_cls
from .tmelt import tmelt as tmelt_cls
from .melting_heat import melting_heat as melting_heat_cls
from .eutectic_temp import eutectic_temp as eutectic_temp_cls
from .speed_of_sound import speed_of_sound as speed_of_sound_cls
from .critical_temperature import critical_temperature as critical_temperature_cls
from .critical_pressure import critical_pressure as critical_pressure_cls
from .critical_volume import critical_volume as critical_volume_cls
from .acentric_factor import acentric_factor as acentric_factor_cls
from .electric_conductivity import electric_conductivity as electric_conductivity_cls
from .dual_electric_conductivity import dual_electric_conductivity as dual_electric_conductivity_cls
from .lithium_diffusivity import lithium_diffusivity as lithium_diffusivity_cls
from .collision_cross_section import collision_cross_section as collision_cross_section_cls

class mixture_child(Group):
    fluent_name = ...
    child_names = ...
    name: name_cls = ...
    chemical_formula: chemical_formula_cls = ...
    density: density_cls = ...
    viscosity: viscosity_cls = ...
    specific_heat: specific_heat_cls = ...
    thermal_conductivity: thermal_conductivity_cls = ...
    premix_laminar_speed: premix_laminar_speed_cls = ...
    premix_laminar_thickness: premix_laminar_thickness_cls = ...
    premix_unburnt_temp: premix_unburnt_temp_cls = ...
    premix_unburnt_cp: premix_unburnt_cp_cls = ...
    premix_unburnt_density: premix_unburnt_density_cls = ...
    premix_heat_trans_coeff: premix_heat_trans_coeff_cls = ...
    premix_critical_strain: premix_critical_strain_cls = ...
    therm_exp_coeff: therm_exp_coeff_cls = ...
    absorption_coefficient: absorption_coefficient_cls = ...
    scattering_coefficient: scattering_coefficient_cls = ...
    scattering_phase_function: scattering_phase_function_cls = ...
    refractive_index: refractive_index_cls = ...
    mass_diffusivity: mass_diffusivity_cls = ...
    species: species_cls = ...
    reactions: reactions_cls = ...
    reaction_mechs: reaction_mechs_cls = ...
    uds_diffusivity: uds_diffusivity_cls = ...
    thermal_diffusivity: thermal_diffusivity_cls = ...
    tmelt: tmelt_cls = ...
    melting_heat: melting_heat_cls = ...
    eutectic_temp: eutectic_temp_cls = ...
    speed_of_sound: speed_of_sound_cls = ...
    critical_temperature: critical_temperature_cls = ...
    critical_pressure: critical_pressure_cls = ...
    critical_volume: critical_volume_cls = ...
    acentric_factor: acentric_factor_cls = ...
    electric_conductivity: electric_conductivity_cls = ...
    dual_electric_conductivity: dual_electric_conductivity_cls = ...
    lithium_diffusivity: lithium_diffusivity_cls = ...
    collision_cross_section: collision_cross_section_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .blade_flapping_cone import blade_flapping_cone as blade_flapping_cone_cls
from .blade_flapping_cyclic_sin import blade_flapping_cyclic_sin as blade_flapping_cyclic_sin_cls
from .blade_flapping_cyclic_cos import blade_flapping_cyclic_cos as blade_flapping_cyclic_cos_cls

class blade_flap_angles(Group):
    fluent_name = ...
    child_names = ...
    blade_flapping_cone: blade_flapping_cone_cls = ...
    blade_flapping_cyclic_sin: blade_flapping_cyclic_sin_cls = ...
    blade_flapping_cyclic_cos: blade_flapping_cyclic_cos_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .case_file import case_file as case_file_cls
from .across_zones import across_zones as across_zones_cls
from .method_2 import method as method_cls
from .load_vector import load_vector as load_vector_cls
from .pre_test import pre_test as pre_test_cls

class auto(Group):
    """
    Enter the menu to set auto partition parameters.
    """

    fluent_name = "auto"

    child_names = \
        ['case_file', 'across_zones', 'method', 'load_vector', 'pre_test']

    _child_classes = dict(
        case_file=case_file_cls,
        across_zones=across_zones_cls,
        method=method_cls,
        load_vector=load_vector_cls,
        pre_test=pre_test_cls,
    )

    return_type = "<object object at 0x7fab933f4160>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .turb_visc_func_mf_child import turb_visc_func_mf_child


class species_spec(NamedObject[turb_visc_func_mf_child], _NonCreatableNamedObjectMixin[turb_visc_func_mf_child]):
    """
    'species_spec' child.
    """

    fluent_name = "species-spec"

    child_object_type: turb_visc_func_mf_child = turb_visc_func_mf_child
    """
    child_object_type of species_spec.
    """
    return_type = "<object object at 0x7f79a6b11800>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .solar_frequency_data import solar_frequency_data as solar_frequency_data_cls
from .solar_filename import solar_filename as solar_filename_cls
from .use_binary_format import use_binary_format as use_binary_format_cls

class autosave_solar_data(Group):
    """
    'autosave_solar_data' child.
    """

    fluent_name = "autosave-solar-data"

    child_names = \
        ['solar_frequency_data', 'solar_filename', 'use_binary_format']

    _child_classes = dict(
        solar_frequency_data=solar_frequency_data_cls,
        solar_filename=solar_filename_cls,
        use_binary_format=use_binary_format_cls,
    )

    return_type = "<object object at 0x7f7d7ffbf610>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .use import use as use_cls
from .user_defined_6 import user_defined as user_defined_cls
from .value_1 import value as value_cls
from .hybrid_optimization import hybrid_optimization as hybrid_optimization_cls

class particle_weight(Group):
    """
    Set DPM particle weight.
    """

    fluent_name = "particle-weight"

    child_names = \
        ['use', 'user_defined', 'value', 'hybrid_optimization']

    _child_classes = dict(
        use=use_cls,
        user_defined=user_defined_cls,
        value=value_cls,
        hybrid_optimization=hybrid_optimization_cls,
    )

    return_type = "<object object at 0x7f7d0bcbc140>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .option import option as option_cls
from .type_10 import type as type_cls
from .id import id as id_cls
from .normal_1 import normal as normal_cls
from .partition import partition as partition_cls

class automatic(Group):
    fluent_name = ...
    child_names = ...
    option: option_cls = ...
    type: type_cls = ...
    id: id_cls = ...
    normal: normal_cls = ...
    partition: partition_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .heat_exchanger import heat_exchanger as heat_exchanger_cls
from .fluid_zone import fluid_zone as fluid_zone_cls
from .boundary_zone import boundary_zone as boundary_zone_cls
from .report_type import report_type as report_type_cls
from .write_to_file import write_to_file as write_to_file_cls
from .file_name_1 import file_name as file_name_cls
from .append_file import append_file as append_file_cls
from .overwrite import overwrite as overwrite_cls

class specific_heat(Command):
    fluent_name = ...
    argument_names = ...
    heat_exchanger: heat_exchanger_cls = ...
    fluid_zone: fluid_zone_cls = ...
    boundary_zone: boundary_zone_cls = ...
    report_type: report_type_cls = ...
    write_to_file: write_to_file_cls = ...
    file_name: file_name_cls = ...
    append_file: append_file_cls = ...
    overwrite: overwrite_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .nodes import nodes as nodes_cls
from .edges import edges as edges_cls
from .faces import faces as faces_cls
from .partitions import partitions as partitions_cls
from .overset_2 import overset as overset_cls
from .gap import gap as gap_cls

class options(Group):
    """
    'options' child.
    """

    fluent_name = "options"

    child_names = \
        ['nodes', 'edges', 'faces', 'partitions', 'overset', 'gap']

    _child_classes = dict(
        nodes=nodes_cls,
        edges=edges_cls,
        faces=faces_cls,
        partitions=partitions_cls,
        overset=overset_cls,
        gap=gap_cls,
    )

    return_type = "<object object at 0x7f79a689a3a0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .x_1 import x as x_cls
from .y_1 import y as y_cls
from .background_color import background_color as background_color_cls

class axes(Group):
    fluent_name = ...
    child_names = ...
    x: x_cls = ...
    y: y_cls = ...
    background_color: background_color_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .residual_smoothing_factor import residual_smoothing_factor as residual_smoothing_factor_cls
from .residual_smoothing_iter_count import residual_smoothing_iter_count as residual_smoothing_iter_count_cls

class residual_smoothing(Group):
    fluent_name = ...
    child_names = ...
    residual_smoothing_factor: residual_smoothing_factor_cls = ...
    residual_smoothing_iter_count: residual_smoothing_iter_count_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .species_mass_flow import species_mass_flow as species_mass_flow_cls
from .element_mass_flow import element_mass_flow as element_mass_flow_cls
from .uds_flow import uds_flow as uds_flow_cls

class flow(Group):
    """
    'flow' child.
    """

    fluent_name = "flow"

    command_names = \
        ['species_mass_flow', 'element_mass_flow', 'uds_flow']

    _child_classes = dict(
        species_mass_flow=species_mass_flow_cls,
        element_mass_flow=element_mass_flow_cls,
        uds_flow=uds_flow_cls,
    )

    return_type = "<object object at 0x7f79a67491a0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .direction_0 import direction_0 as direction_0_cls
from .direction_1 import direction_1 as direction_1_cls
from .youngs_modulus_0 import youngs_modulus_0 as youngs_modulus_0_cls
from .youngs_modulus_1 import youngs_modulus_1 as youngs_modulus_1_cls
from .youngs_modulus_2 import youngs_modulus_2 as youngs_modulus_2_cls
from .shear_modulus_01 import shear_modulus_01 as shear_modulus_01_cls
from .shear_modulus_12 import shear_modulus_12 as shear_modulus_12_cls
from .shear_modulus_02 import shear_modulus_02 as shear_modulus_02_cls

class orthotropic_structure_ym(Group):
    """
    'orthotropic_structure_ym' child.
    """

    fluent_name = "orthotropic-structure-ym"

    child_names = \
        ['direction_0', 'direction_1', 'youngs_modulus_0', 'youngs_modulus_1',
         'youngs_modulus_2', 'shear_modulus_01', 'shear_modulus_12',
         'shear_modulus_02']

    _child_classes = dict(
        direction_0=direction_0_cls,
        direction_1=direction_1_cls,
        youngs_modulus_0=youngs_modulus_0_cls,
        youngs_modulus_1=youngs_modulus_1_cls,
        youngs_modulus_2=youngs_modulus_2_cls,
        shear_modulus_01=shear_modulus_01_cls,
        shear_modulus_12=shear_modulus_12_cls,
        shear_modulus_02=shear_modulus_02_cls,
    )

    return_type = "<object object at 0x7f79c84e4500>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .mf_1 import mf as mf_cls
from .urf import urf as urf_cls

class solution_controls(Command):
    """
    Specification of mapped frequency and under-relaxation factor for mapped interfaces.
    
    Parameters
    ----------
        mf : int
            'mf' child.
        urf : real
            'urf' child.
    
    """

    fluent_name = "solution-controls"

    argument_names = \
        ['mf', 'urf']

    _child_classes = dict(
        mf=mf_cls,
        urf=urf_cls,
    )

    return_type = "<object object at 0x7f7d51115ef0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .set_cgns_export_filetype import set_cgns_export_filetype as set_cgns_export_filetype_cls

class settings(Group):
    """
    Enter the export settings menu.
    """

    fluent_name = "settings"

    command_names = \
        ['set_cgns_export_filetype']

    _child_classes = dict(
        set_cgns_export_filetype=set_cgns_export_filetype_cls,
    )

    return_type = "<object object at 0x7f79e9239170>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .zone_names_4 import zone_names as zone_names_cls
from .domain import domain as domain_cls
from .quantities import quantities as quantities_cls
from .min_2 import min as min_cls
from .max_2 import max as max_cls
from .mean_1 import mean as mean_cls
from .rmse_1 import rmse as rmse_cls
from .moving_average_1 import moving_average as moving_average_cls
from .average_over import average_over as average_over_cls

class add_datasets(Command):
    fluent_name = ...
    argument_names = ...
    zone_names: zone_names_cls = ...
    domain: domain_cls = ...
    quantities: quantities_cls = ...
    min: min_cls = ...
    max: max_cls = ...
    mean: mean_cls = ...
    rmse: rmse_cls = ...
    moving_average: moving_average_cls = ...
    average_over: average_over_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .data_sampling import data_sampling as data_sampling_cls
from .sampling_interval import sampling_interval as sampling_interval_cls
from .statistics_shear_stress import statistics_shear_stress as statistics_shear_stress_cls
from .statistics_heat_flux import statistics_heat_flux as statistics_heat_flux_cls
from .wall_statistics import wall_statistics as wall_statistics_cls
from .force_statistics import force_statistics as force_statistics_cls
from .time_statistics_dpm import time_statistics_dpm as time_statistics_dpm_cls
from .species_list import species_list as species_list_cls
from .statistics_mixture_fraction import statistics_mixture_fraction as statistics_mixture_fraction_cls
from .statistics_reaction_progress import statistics_reaction_progress as statistics_reaction_progress_cls
from .save_cff_unsteady_statistics import save_cff_unsteady_statistics as save_cff_unsteady_statistics_cls
from .setup_unsteady_statistics import setup_unsteady_statistics as setup_unsteady_statistics_cls

class data_sampling(Group):
    """
    'data_sampling' child.
    """

    fluent_name = "data-sampling"

    child_names = \
        ['data_sampling', 'sampling_interval', 'statistics_shear_stress',
         'statistics_heat_flux', 'wall_statistics', 'force_statistics',
         'time_statistics_dpm', 'species_list', 'statistics_mixture_fraction',
         'statistics_reaction_progress', 'save_cff_unsteady_statistics']

    command_names = \
        ['setup_unsteady_statistics']

    _child_classes = dict(
        data_sampling=data_sampling_cls,
        sampling_interval=sampling_interval_cls,
        statistics_shear_stress=statistics_shear_stress_cls,
        statistics_heat_flux=statistics_heat_flux_cls,
        wall_statistics=wall_statistics_cls,
        force_statistics=force_statistics_cls,
        time_statistics_dpm=time_statistics_dpm_cls,
        species_list=species_list_cls,
        statistics_mixture_fraction=statistics_mixture_fraction_cls,
        statistics_reaction_progress=statistics_reaction_progress_cls,
        save_cff_unsteady_statistics=save_cff_unsteady_statistics_cls,
        setup_unsteady_statistics=setup_unsteady_statistics_cls,
    )

    return_type = "<object object at 0x7fd5ebc46ac0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .mass_flux_correction_method import mass_flux_correction_method as mass_flux_correction_method_cls
from .hybrid_mode_selection import hybrid_mode_selection as hybrid_mode_selection_cls

class expert(Group):
    fluent_name = ...
    child_names = ...
    mass_flux_correction_method: mass_flux_correction_method_cls = ...
    hybrid_mode_selection: hybrid_mode_selection_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .initialization_type_1 import initialization_type as initialization_type_cls
from .data_file_name import data_file_name as data_file_name_cls
from .init_from_solution_1 import init_from_solution as init_from_solution_cls
from .data_file_name2 import data_file_name2 as data_file_name2_cls

class automatic_initialization(Command):
    """
    Define how the case is to be initialized automatically.
    
    Parameters
    ----------
        initialization_type : str
            'initialization_type' child.
        data_file_name : str
            'data_file_name' child.
        init_from_solution : str
            'init_from_solution' child.
        data_file_name2 : str
            'data_file_name2' child.
    
    """

    fluent_name = "automatic-initialization"

    argument_names = \
        ['initialization_type', 'data_file_name', 'init_from_solution',
         'data_file_name2']

    _child_classes = dict(
        initialization_type=initialization_type_cls,
        data_file_name=data_file_name_cls,
        init_from_solution=init_from_solution_cls,
        data_file_name2=data_file_name2_cls,
    )

    return_type = "<object object at 0x7fab936f45d0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .number_of_blades import number_of_blades as number_of_blades_cls
from .tip_radius import tip_radius as tip_radius_cls
from .root_radius import root_radius as root_radius_cls
from .rotor_speed import rotor_speed as rotor_speed_cls

class basic_info(Group):
    fluent_name = ...
    child_names = ...
    number_of_blades: number_of_blades_cls = ...
    tip_radius: tip_radius_cls = ...
    root_radius: root_radius_cls = ...
    rotor_speed: rotor_speed_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .phase_14 import phase as phase_cls
from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
from .angular import angular as angular_cls
from .p_jump import p_jump as p_jump_cls
from .ai import ai as ai_cls
from .aj import aj as aj_cls
from .ak import ak as ak_cls
from .x_origin import x_origin as x_origin_cls
from .y_origin import y_origin as y_origin_cls
from .z_origin import z_origin as z_origin_cls
from .shift_x import shift_x as shift_x_cls
from .shift_y import shift_y as shift_y_cls
from .shift_z import shift_z as shift_z_cls
from .per_angle import per_angle as per_angle_cls

class periodic_child(Group):
    fluent_name = ...
    child_names = ...
    phase: phase_cls = ...
    geom_disable: geom_disable_cls = ...
    geom_dir_spec: geom_dir_spec_cls = ...
    geom_dir_x: geom_dir_x_cls = ...
    geom_dir_y: geom_dir_y_cls = ...
    geom_dir_z: geom_dir_z_cls = ...
    geom_levels: geom_levels_cls = ...
    geom_bgthread: geom_bgthread_cls = ...
    angular: angular_cls = ...
    p_jump: p_jump_cls = ...
    ai: ai_cls = ...
    aj: aj_cls = ...
    ak: ak_cls = ...
    x_origin: x_origin_cls = ...
    y_origin: y_origin_cls = ...
    z_origin: z_origin_cls = ...
    shift_x: shift_x_cls = ...
    shift_y: shift_y_cls = ...
    shift_z: shift_z_cls = ...
    per_angle: per_angle_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .rich_equivalence_ratio_limit import rich_equivalence_ratio_limit as rich_equivalence_ratio_limit_cls
from .exponential_factor_beta import exponential_factor_beta as exponential_factor_beta_cls

class equilibrium_rich_flammability_options(Group):
    """
    'equilibrium_rich_flammability_options' child.
    """

    fluent_name = "equilibrium-rich-flammability-options"

    child_names = \
        ['rich_equivalence_ratio_limit', 'exponential_factor_beta']

    _child_classes = dict(
        rich_equivalence_ratio_limit=rich_equivalence_ratio_limit_cls,
        exponential_factor_beta=exponential_factor_beta_cls,
    )

    return_type = "<object object at 0x7f7d7fc63100>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .type_of_smoothing import type_of_smoothing as type_of_smoothing_cls
from .number_of_iterations import number_of_iterations as number_of_iterations_cls
from .relaxtion_factor import relaxtion_factor as relaxtion_factor_cls
from .percentage_of_cells import percentage_of_cells as percentage_of_cells_cls
from .skewness_threshold import skewness_threshold as skewness_threshold_cls

class smooth_mesh(Command):
    fluent_name = ...
    argument_names = ...
    type_of_smoothing: type_of_smoothing_cls = ...
    number_of_iterations: number_of_iterations_cls = ...
    relaxtion_factor: relaxtion_factor_cls = ...
    percentage_of_cells: percentage_of_cells_cls = ...
    skewness_threshold: skewness_threshold_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .heat_exchanger import heat_exchanger as heat_exchanger_cls
from .fluid_zone import fluid_zone as fluid_zone_cls
from .boundary_zone import boundary_zone as boundary_zone_cls
from .report_type import report_type as report_type_cls
from .write_to_file import write_to_file as write_to_file_cls
from .file_name_1 import file_name as file_name_cls
from .append_file import append_file as append_file_cls
from .overwrite import overwrite as overwrite_cls

class computed_heat_rejection(Command):
    """
    'computed_heat_rejection' command.
    
    Parameters
    ----------
        heat_exchanger : str
            'heat_exchanger' child.
        fluid_zone : str
            'fluid_zone' child.
        boundary_zone : str
            'boundary_zone' child.
        report_type : str
            'report_type' child.
        write_to_file : bool
            'write_to_file' child.
        file_name : str
            'file_name' child.
        append_file : bool
            'append_file' child.
        overwrite : bool
            'overwrite' child.
    
    """

    fluent_name = "computed-heat-rejection"

    argument_names = \
        ['heat_exchanger', 'fluid_zone', 'boundary_zone', 'report_type',
         'write_to_file', 'file_name', 'append_file', 'overwrite']

    _child_classes = dict(
        heat_exchanger=heat_exchanger_cls,
        fluid_zone=fluid_zone_cls,
        boundary_zone=boundary_zone_cls,
        report_type=report_type_cls,
        write_to_file=write_to_file_cls,
        file_name=file_name_cls,
        append_file=append_file_cls,
        overwrite=overwrite_cls,
    )

    return_type = "<object object at 0x7f79a67493c0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .dispersion_force_in_momentum import dispersion_force_in_momentum as dispersion_force_in_momentum_cls
from .dispersion_in_relative_velocity import dispersion_in_relative_velocity as dispersion_in_relative_velocity_cls

class multiphase_options(Group):
    fluent_name = ...
    child_names = ...
    dispersion_force_in_momentum: dispersion_force_in_momentum_cls = ...
    dispersion_in_relative_velocity: dispersion_in_relative_velocity_cls = ...
    return_type = ...
